@@ -7,22 +7,18 @@
 #include "compositeuploadjob.h"
 #include "lanlinkprovider.h"
 #include "plugins/share/shareplugin.h"
-#include "qtcompat_p.h"
 #include <KJobTrackerInterface>
 #include <KLocalizedString>
 #include <core_debug.h>
 #include <daemon.h>
+#include <device.h>
 
-#ifdef HAVE_KIO
-#include <kio/global.h>
-#endif
-
-CompositeUploadJob::CompositeUploadJob(const QString &deviceId, bool displayNotification)
-    : KCompositeJob()
+CompositeUploadJob::CompositeUploadJob(Device *device, bool displayNotification)
+    : KCompositeJob(device)
     , m_server(new Server(this))
     , m_socket(nullptr)
     , m_port(0)
-    , m_deviceId(deviceId)
+    , m_device(device)
     , m_running(false)
     , m_currentJobNum(1)
     , m_totalJobs(0)
@@ -95,30 +91,23 @@ void CompositeUploadJob::startNextSubJob()
     m_currentJobSendPayloadSize = 0;
     emitDescription(m_currentJob->getNetworkPacket().get<QString>(QStringLiteral("filename")));
 
-#ifdef SAILFISHOS
-    connect(m_currentJob, SIGNAL(processedAmount(KJob *, KJob::Unit, qulonglong)), this, SLOT(slotProcessedAmount(KJob *, KJob::Unit, qulonglong)));
-#else
-    connect(m_currentJob, QOverload<KJob *, KJob::Unit, qulonglong>::of(&UploadJob::processedAmount), this, &CompositeUploadJob::slotProcessedAmount);
-#endif
+    connect(m_currentJob, &UploadJob::processedAmountChanged, this, &CompositeUploadJob::slotProcessedAmount);
+
     // Already done by KCompositeJob
     // connect(m_currentJob, &KJob::result, this, &CompositeUploadJob::slotResult);
 
     // TODO: Create a copy of the networkpacket that can be re-injected if sending via lan fails?
     NetworkPacket np = m_currentJob->getNetworkPacket();
-#if QT_VERSION < QT_VERSION_CHECK(5, 8, 0)
-    np.setPayload({}, np.payloadSize());
-#else
     np.setPayload(nullptr, np.payloadSize());
-#endif
     np.setPayloadTransferInfo({{QStringLiteral("port"), m_port}});
     np.set<int>(QStringLiteral("numberOfFiles"), m_totalJobs);
     np.set<quint64>(QStringLiteral("totalPayloadSize"), m_totalPayloadSize);
 
-    if (Daemon::instance()->getDevice(m_deviceId)->sendPacket(np)) {
+    if (m_device->sendPacket(np)) {
         m_server->resumeAccepting();
     } else {
         setError(SendingNetworkPacketFailed);
-        setErrorText(i18n("Failed to send packet to %1", Daemon::instance()->getDevice(m_deviceId)->name()));
+        setErrorText(i18n("Failed to send packet to %1", m_device->name()));
 
         emitResult();
     }
@@ -137,57 +126,39 @@ void CompositeUploadJob::newConnection()
 
     m_currentJob->setSocket(m_socket);
 
-    connect(m_socket, &QSslSocket::disconnected, this, &CompositeUploadJob::socketDisconnected);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    connect(m_socket, QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::error), this, &CompositeUploadJob::socketError);
-#else
-    connect(m_socket, &QAbstractSocket::errorOccurred, this, &CompositeUploadJob::socketError);
-#endif
-    connect(m_socket, QOverload<const QList<QSslError> &>::of(&QSslSocket::sslErrors), this, &CompositeUploadJob::sslError);
-    connect(m_socket, &QSslSocket::encrypted, this, &CompositeUploadJob::encrypted);
+    connect(m_socket, &QSslSocket::disconnected, this, [this]() {
+        m_socket->close();
+    });
+    connect(m_socket, &QAbstractSocket::errorOccurred, this, [this](QAbstractSocket::SocketError error) {
+        qCDebug(KDECONNECT_CORE) << "Error in socket occurred" << error;
+        // Do not close the socket because when android closes the socket (share is cancelled) closing the socket leads to a cyclic socketError and eventually a
+        // segv
+        setError(SocketError);
+        emitResult();
 
-    LanLinkProvider::configureSslSocket(m_socket, m_deviceId, true);
+        m_running = false;
+    });
+    connect(m_socket, &QSslSocket::sslErrors, this, [this](const QList<QSslError> &errors) {
+        qCDebug(KDECONNECT_CORE) << "Received ssl errors" << errors;
+        m_socket->close();
+        setError(SslError);
+        emitResult();
+
+        m_running = false;
+    });
+    connect(m_socket, &QSslSocket::encrypted, this, [this]() {
+        if (!m_timer.isValid()) {
+            m_timer.start();
+        }
+
+        m_currentJob->start();
+    });
+
+    LanLinkProvider::configureSslSocket(m_socket, m_device->id(), true);
 
     m_socket->startServerEncryption();
 }
 
-void CompositeUploadJob::socketDisconnected()
-{
-    m_socket->close();
-}
-
-void CompositeUploadJob::socketError(QAbstractSocket::SocketError error)
-{
-    Q_UNUSED(error);
-
-    // Do not close the socket because when android closes the socket (share is cancelled) closing the socket leads to a cyclic socketError and eventually a
-    // segv
-    setError(SocketError);
-    emitResult();
-
-    m_running = false;
-}
-
-void CompositeUploadJob::sslError(const QList<QSslError> &errors)
-{
-    Q_UNUSED(errors);
-
-    m_socket->close();
-    setError(SslError);
-    emitResult();
-
-    m_running = false;
-}
-
-void CompositeUploadJob::encrypted()
-{
-    if (!m_timer.isValid()) {
-        m_timer.start();
-    }
-
-    m_currentJob->start();
-}
-
 bool CompositeUploadJob::addSubjob(KJob *job)
 {
     if (UploadJob *uploadJob = qobject_cast<UploadJob *>(job)) {
@@ -225,13 +196,13 @@ bool CompositeUploadJob::addSubjob(KJob *job)
 
 void CompositeUploadJob::sendUpdatePacket()
 {
+    m_updatePacketPending = false;
+
     NetworkPacket np(PACKET_TYPE_SHARE_REQUEST_UPDATE);
     np.set<int>(QStringLiteral("numberOfFiles"), m_totalJobs);
     np.set<quint64>(QStringLiteral("totalPayloadSize"), m_totalPayloadSize);
 
-    Daemon::instance()->getDevice(m_deviceId)->sendPacket(np);
-
-    m_updatePacketPending = false;
+    m_device->sendPacket(np);
 }
 
 bool CompositeUploadJob::doKill()
@@ -245,10 +216,8 @@ bool CompositeUploadJob::doKill()
     return true;
 }
 
-void CompositeUploadJob::slotProcessedAmount(KJob *job, KJob::Unit unit, qulonglong amount)
+void CompositeUploadJob::slotProcessedAmount(KJob * /*job*/, KJob::Unit unit, qulonglong amount)
 {
-    Q_UNUSED(job);
-
     m_currentJobSendPayloadSize = amount;
     quint64 uploaded = m_totalSendPayloadSize + m_currentJobSendPayloadSize;
 
@@ -284,8 +253,10 @@ void CompositeUploadJob::slotResult(KJob *job)
 
 void CompositeUploadJob::emitDescription(const QString &currentFileName)
 {
-    Q_EMIT description(this, i18n("Sending to %1", Daemon::instance()->getDevice(this->m_deviceId)->name()), {i18n("File"), currentFileName}, {});
+    Q_EMIT description(this, i18n("Sending to %1", m_device->name()), {i18n("File"), currentFileName}, {});
 
     setProcessedAmount(Files, m_currentJobNum);
     setTotalAmount(Files, m_totalJobs);
 }
+
+#include "moc_compositeuploadjob.cpp"
