@@ -18,12 +18,9 @@
 #include <mstcpip.h>
 #endif
 
-#if defined(Q_OS_WIN) || defined(Q_OS_FREEBSD)
-#include <QNetworkInterface>
-#endif
-
 #include <QHostInfo>
 #include <QMetaEnum>
+#include <QNetworkInterface>
 #include <QNetworkProxy>
 #include <QSslCipher>
 #include <QSslConfiguration>
@@ -37,6 +34,10 @@
 #include "kdeconnectconfig.h"
 #include "landevicelink.h"
 
+// The size here is arbitrary, it needs to be considerably long as it includes the capabilities but there needs to be a limit.
+// Tested between my systems and I get around 2000 per identity package.
+static const int MAX_IDENTITY_PACKET_SIZE = 8192;
+
 static const int MAX_UNPAIRED_CONNECTIONS = 42;
 static const int MAX_REMEMBERED_IDENTITY_PACKETS = 42;
 
@@ -189,28 +190,7 @@ void LanLinkProvider::broadcastUdpIdentityPacket()
     }
     qCDebug(KDECONNECT_CORE) << "Broadcasting identity packet";
 
-    QList<QHostAddress> addresses = getBroadcastAddresses();
-
-#if defined(Q_OS_WIN) || defined(Q_OS_FREEBSD)
-    // On Windows and FreeBSD we need to broadcast from every local IP address to reach all networks
-    QUdpSocket sendSocket;
-    sendSocket.setProxy(QNetworkProxy::NoProxy);
-    for (const QNetworkInterface &iface : QNetworkInterface::allInterfaces()) {
-        if ((iface.flags() & QNetworkInterface::IsUp) && (iface.flags() & QNetworkInterface::IsRunning) && (iface.flags() & QNetworkInterface::CanBroadcast)) {
-            for (const QNetworkAddressEntry &ifaceAddress : iface.addressEntries()) {
-                QHostAddress sourceAddress = ifaceAddress.ip();
-                if (sourceAddress.protocol() == QAbstractSocket::IPv4Protocol && sourceAddress != QHostAddress::LocalHost) {
-                    qCDebug(KDECONNECT_CORE) << "Broadcasting as" << sourceAddress;
-                    sendSocket.bind(sourceAddress);
-                    sendUdpIdentityPacket(sendSocket, addresses);
-                    sendSocket.close();
-                }
-            }
-        }
-    }
-#else
-    sendUdpIdentityPacket(addresses);
-#endif
+    sendUdpIdentityPacket(getBroadcastAddresses());
 }
 
 QList<QHostAddress> LanLinkProvider::getBroadcastAddresses()
@@ -238,7 +218,22 @@ QList<QHostAddress> LanLinkProvider::getBroadcastAddresses()
 
 void LanLinkProvider::sendUdpIdentityPacket(const QList<QHostAddress> &addresses)
 {
-    sendUdpIdentityPacket(m_udpSocket, addresses);
+    // Broadcast from every local IP address to reach all networks
+    QUdpSocket sendSocket;
+    sendSocket.setProxy(QNetworkProxy::NoProxy);
+    for (const QNetworkInterface &iface : QNetworkInterface::allInterfaces()) {
+        if ((iface.flags() & QNetworkInterface::IsUp) && (iface.flags() & QNetworkInterface::IsRunning)) {
+            for (const QNetworkAddressEntry &ifaceAddress : iface.addressEntries()) {
+                QHostAddress sourceAddress = ifaceAddress.ip();
+                if (sourceAddress.protocol() == QAbstractSocket::IPv4Protocol && sourceAddress != QHostAddress::LocalHost) {
+                    qCDebug(KDECONNECT_CORE) << "Broadcasting as" << sourceAddress;
+                    sendSocket.bind(sourceAddress);
+                    sendUdpIdentityPacket(sendSocket, addresses);
+                    sendSocket.close();
+                }
+            }
+        }
+    }
 }
 
 void LanLinkProvider::sendUdpIdentityPacket(QUdpSocket &socket, const QList<QHostAddress> &addresses)
@@ -411,7 +406,7 @@ void LanLinkProvider::tcpSocketConnected()
         m_udpSocket.writeDatagram(np2.serialize(), m_receivedIdentityPackets[socket].sender, UDP_PORT);
 
         // Disconnect should trigger deleteLater, which should remove the socket from m_receivedIdentityPackets
-        socket->disconnectFromHost();
+        socket->abort();
     }
 }
 
@@ -427,6 +422,7 @@ void LanLinkProvider::encrypted()
 
     NetworkPacket *identityPacket = m_receivedIdentityPackets[socket].np;
 
+    QString deviceId = identityPacket->get<QString>(QStringLiteral("deviceId"));
     int protocolVersion = identityPacket->get<int>(QStringLiteral("protocolVersion"), -1);
     if (protocolVersion >= 8) {
         disconnect(socket, &QObject::destroyed, nullptr, nullptr);
@@ -435,7 +431,12 @@ void LanLinkProvider::encrypted()
         NetworkPacket myIdentity = KdeConnectConfig::instance().deviceInfo().toIdentityPacket();
         socket->write(myIdentity.serialize());
         socket->flush();
-        connect(socket, &QIODevice::readyRead, this, [this, socket, protocolVersion]() {
+        connect(socket, &QIODevice::readyRead, this, [this, socket, protocolVersion, deviceId]() {
+            if (socket->bytesAvailable() > MAX_IDENTITY_PACKET_SIZE) {
+                qCWarning(KDECONNECT_CORE) << "Remote device sent a packet too large";
+                socket->abort();
+                return;
+            }
             if (!socket->canReadLine()) {
                 // This can happen if the packet is large enough to be split in two chunks
                 return;
@@ -446,12 +447,20 @@ void LanLinkProvider::encrypted()
             bool success = NetworkPacket::unserialize(identityString, secureIdentityPacket);
             if (!success || !DeviceInfo::isValidIdentityPacket(secureIdentityPacket)) {
                 qCWarning(KDECONNECT_CORE, "Remote device doesn't correctly implement protocol version 8");
-                disconnect(socket, &QObject::destroyed, nullptr, nullptr);
+                socket->abort();
                 return;
             }
             int newProtocolVersion = secureIdentityPacket->get<int>(QStringLiteral("protocolVersion"), 0);
             if (newProtocolVersion != protocolVersion) {
                 qCWarning(KDECONNECT_CORE) << "Protocol version changed half-way through the handshake:" << protocolVersion << "->" << newProtocolVersion;
+                socket->abort();
+                return;
+            }
+            QString newDeviceId = secureIdentityPacket->get<QString>(QStringLiteral("deviceId"));
+            if (newDeviceId != deviceId) {
+                qCWarning(KDECONNECT_CORE) << "Device ID changed half-way through the handshake:" << deviceId << "->" << newDeviceId;
+                socket->abort();
+                return;
             }
             DeviceInfo deviceInfo = DeviceInfo::FromIdentityPacketAndCert(*secureIdentityPacket, socket->peerCertificate());
 
@@ -471,10 +480,6 @@ void LanLinkProvider::encrypted()
 
 void LanLinkProvider::sslErrors(const QList<QSslError> &errors)
 {
-    QSslSocket *socket = qobject_cast<QSslSocket *>(sender());
-    if (!socket)
-        return;
-
     bool fatal = false;
     for (const QSslError &error : errors) {
         if (error.error() != QSslError::SelfSignedCertificate) {
@@ -486,8 +491,11 @@ void LanLinkProvider::sslErrors(const QList<QSslError> &errors)
     }
 
     if (fatal) {
-        // Disconnect should trigger deleteLater, which should remove the socket from m_receivedIdentityPackets
-        socket->disconnectFromHost();
+        QSslSocket *socket = qobject_cast<QSslSocket *>(sender());
+        if (socket) {
+            // Disconnect should trigger deleteLater
+            socket->abort();
+        }
     }
 }
 
@@ -511,8 +519,8 @@ void LanLinkProvider::newConnection()
         timer->setInterval(1000);
         connect(socket, &QSslSocket::encrypted, timer, &QObject::deleteLater);
         connect(timer, &QTimer::timeout, socket, [socket] {
-            qCWarning(KDECONNECT_CORE) << "LanLinkProvider/newConnection: Host timed out without sending any identity." << socket->peerAddress();
-            socket->disconnectFromHost();
+            qCWarning(KDECONNECT_CORE) << "LanLinkProvider/newTcpConnection: Host timed out without sending any identity." << socket->peerAddress();
+            socket->abort();
         });
         timer->start();
     }
@@ -522,12 +530,10 @@ void LanLinkProvider::newConnection()
 void LanLinkProvider::dataReceived()
 {
     QSslSocket *socket = qobject_cast<QSslSocket *>(sender());
-    // the size here is arbitrary and is now at 8192 bytes. It needs to be considerably long as it includes the capabilities but there needs to be a limit
-    // Tested between my systems and I get around 2000 per identity package.
-    if (socket->bytesAvailable() > 8192) {
-        qCWarning(KDECONNECT_CORE) << "LanLinkProvider/newConnection: Suspiciously long identity package received. Closing connection." << socket->peerAddress()
-                                   << socket->bytesAvailable();
-        socket->disconnectFromHost();
+    if (socket->bytesAvailable() > MAX_IDENTITY_PACKET_SIZE) {
+        qCWarning(KDECONNECT_CORE) << "LanLinkProvider/newTcpConnection: Suspiciously long identity package received. Closing connection."
+                                   << socket->peerAddress() << socket->bytesAvailable();
+        socket->abort();
         return;
     }
 
@@ -644,7 +650,7 @@ void LanLinkProvider::addLink(QSslSocket *socket, const DeviceInfo &deviceInfo)
     QString certDeviceId = socket->peerCertificate().subjectDisplayName();
     DBusHelper::filterNonExportableCharacters(certDeviceId);
     if (deviceInfo.id != certDeviceId) {
-        socket->disconnectFromHost();
+        socket->abort();
         qCWarning(KDECONNECT_CORE) << "DeviceID in cert doesn't match deviceID in identity packet." << deviceInfo.id << "vs" << certDeviceId;
         return;
     }
@@ -670,7 +676,7 @@ void LanLinkProvider::addLink(QSslSocket *socket, const DeviceInfo &deviceInfo)
         bool isDeviceTrusted = KdeConnectConfig::instance().trustedDevices().contains(deviceInfo.id);
         if (!isDeviceTrusted && m_links.size() > MAX_UNPAIRED_CONNECTIONS) {
             qCWarning(KDECONNECT_CORE) << "Too many unpaired devices to remember them all. Ignoring" << deviceInfo.id;
-            socket->disconnectFromHost();
+            socket->abort();
             socket->deleteLater();
             return;
         }
