@@ -12,7 +12,7 @@ struct KdeConnectPluginPrivate {
     Device *m_device;
     QString m_pluginName;
     QSet<QString> m_outgoingCapabilties;
-    KdeConnectPluginConfig *m_config;
+    KdeConnectPluginConfig *m_config = nullptr;
     QString iconName;
 };
 
@@ -20,10 +20,12 @@ KdeConnectPlugin::KdeConnectPlugin(QObject *parent, const QVariantList &args)
     : QObject(parent)
     , d(new KdeConnectPluginPrivate)
 {
+    Q_ASSERT(args.length() == 4);
     d->m_device = qvariant_cast<Device *>(args.at(0));
     d->m_pluginName = args.at(1).toString();
-    d->m_outgoingCapabilties = args.at(2).toStringList().toSet();
-    d->m_config = nullptr;
+
+    const QStringList cap = args.at(2).toStringList();
+    d->m_outgoingCapabilties = QSet(cap.begin(), cap.end());
     d->iconName = args.at(3).toString();
 }
 
@@ -38,9 +40,7 @@ KdeConnectPluginConfig *KdeConnectPlugin::config() const
 
 KdeConnectPlugin::~KdeConnectPlugin()
 {
-    if (d->m_config) {
-        delete d->m_config;
-    }
+    delete d->m_config;
 }
 
 const Device *KdeConnectPlugin::device()
@@ -69,7 +69,13 @@ QString KdeConnectPlugin::dbusPath() const
     return {};
 }
 
+void KdeConnectPlugin::receivePacket(const NetworkPacket &np)
+{
+    qCWarning(KDECONNECT_CORE) << metaObject()->className() << "received a packet of type" << np.type() << "but doesn't implement receivePacket";
+}
 QString KdeConnectPlugin::iconName() const
 {
     return d->iconName;
 }
+
+#include "moc_kdeconnectplugin.cpp"
