@@ -7,52 +7,45 @@
  */
 
 #include "mousepadplugin.h"
-#include <KPluginFactory>
 #include <KLocalizedString>
+#include <KPluginFactory>
 #include <QGuiApplication>
 
-#if HAVE_WINDOWS
-    #include "windowsremoteinput.h"
-#elif HAVE_MACOS
-    #include "macosremoteinput.h"
+#if defined(Q_OS_WIN)
+#include "windowsremoteinput.h"
+#elif defined(Q_OS_MACOS)
+#include "macosremoteinput.h"
 #else
-    #if HAVE_X11
-        #include "x11remoteinput.h"
-    #endif
-    #if HAVE_WAYLAND
-        #include "waylandremoteinput.h"
-    #endif
+#include "waylandremoteinput.h"
+#if WITH_X11
+#include "x11remoteinput.h"
+#endif
 #endif
-
 
 K_PLUGIN_CLASS_WITH_JSON(MousepadPlugin, "kdeconnect_mousepad.json")
 
-MousepadPlugin::MousepadPlugin(QObject* parent, const QVariantList& args)
+MousepadPlugin::MousepadPlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
     , m_impl(nullptr)
 {
-#if HAVE_WINDOWS
+#if defined(Q_OS_WIN)
     m_impl = new WindowsRemoteInput(this);
-#elif HAVE_MACOS
+#elif defined(Q_OS_MACOS)
     m_impl = new MacOSRemoteInput(this);
 #else
-    #if HAVE_X11
-    if (QGuiApplication::platformName() == QLatin1String("xcb")) {
-        m_impl = new X11RemoteInput(this);
-    }
-    #endif
-
-    #if HAVE_WAYLAND
     if (QGuiApplication::platformName().startsWith(QLatin1String("wayland"), Qt::CaseInsensitive)) {
         m_impl = new WaylandRemoteInput(this);
     }
-    #endif
+#if WITH_X11
+    if (QGuiApplication::platformName() == QLatin1String("xcb")) {
+        m_impl = new X11RemoteInput(this);
+    }
+#endif
 #endif
 
     if (!m_impl) {
         qDebug() << "KDE Connect was built without" << QGuiApplication::platformName() << "support";
     }
-
 }
 
 MousepadPlugin::~MousepadPlugin()
@@ -60,17 +53,15 @@ MousepadPlugin::~MousepadPlugin()
     delete m_impl;
 }
 
-bool MousepadPlugin::receivePacket(const NetworkPacket& np)
+void MousepadPlugin::receivePacket(const NetworkPacket &np)
 {
     if (m_impl) {
-        return m_impl->handlePacket(np);
-    } else {
-        return false;
+        m_impl->handlePacket(np);
     }
 }
 
-
-void MousepadPlugin::connected() {
+void MousepadPlugin::connected()
+{
     NetworkPacket np(PACKET_TYPE_MOUSEPAD_KEYBOARDSTATE);
     if (m_impl) {
         np.set<bool>(QStringLiteral("state"), m_impl->hasKeyboardSupport());
@@ -78,4 +69,5 @@ void MousepadPlugin::connected() {
     sendPacket(np);
 }
 
+#include "moc_mousepadplugin.cpp"
 #include "mousepadplugin.moc"
